@@ -40,14 +40,20 @@ impl Observer {
 
       TdType::UpdateCall(value) => value.extra(),
 
+      TdType::UpdateChatAction(value) => value.extra(),
+
       TdType::UpdateChatActionBar(value) => value.extra(),
 
       TdType::UpdateChatDefaultDisableNotification(value) => value.extra(),
 
+      TdType::UpdateChatDefaultMessageSenderId(value) => value.extra(),
+
       TdType::UpdateChatDraftMessage(value) => value.extra(),
 
       TdType::UpdateChatFilters(value) => value.extra(),
 
+      TdType::UpdateChatHasProtectedContent(value) => value.extra(),
+
       TdType::UpdateChatHasScheduledMessages(value) => value.extra(),
 
       TdType::UpdateChatIsBlocked(value) => value.extra(),
@@ -196,8 +202,6 @@ impl Observer {
 
       TdType::UpdateUser(value) => value.extra(),
 
-      TdType::UpdateUserChatAction(value) => value.extra(),
-
       TdType::UpdateUserFullInfo(value) => value.extra(),
 
       TdType::UpdateUserPrivacySettingRules(value) => value.extra(),
